==> haskell-crypto-cipher-types-0.0.9-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-crypto-cipher-types/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-cipher-types
version: 0.0.9
id: crypto-cipher-types-0.0.9-d75467a29912eeec0d085743eedba9cf
key: crypt_AkbdiYWeXYI5D4jAOMIXve
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-crypto-cipher
synopsis: Generic cryptography cipher types
description:
    Generic cryptography cipher types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules: Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
                Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
                Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
                Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-cipher-types-0.0.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-cipher-types-0.0.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/crypto-cipher-types-0.0.9
hs-libraries: HScrypto-cipher-types-0.0.9-AkbdiYWeXYI5D4jAOMIXve
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    securemem-0.1.9-b2776257967087e0982593cb67cce3c9
haddock-interfaces: /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-cipher-types-0.0.9-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-crypto-cipher-types/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-cipher-types
version: 0.0.9
id: crypto-cipher-types-0.0.9-a95ebaba569741079643caffca2b7299
key: crypt_3Ksk0JfsfZb4yvJa7XkhEJ
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-crypto-cipher
synopsis: Generic cryptography cipher types
description:
    Generic cryptography cipher types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules: Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
                Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
                Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
                Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-cipher-types-0.0.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-cipher-types-0.0.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/crypto-cipher-types-0.0.9
hs-libraries: HScrypto-cipher-types-0.0.9-3Ksk0JfsfZb4yvJa7XkhEJ
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    securemem-0.1.9-01ec912d1ae68740f3ee3b7079e4f920
haddock-interfaces: /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
